# coding: utf-8
from .base import ManagerApi
from maxipago.requesters.customer import CustomerRequester
from maxipago.resources.customer import CustomerAddResource, CustomerDeleteResource, CustomerUpdateResource


class CustomerManager(ManagerApi):

    def add(self, **kwargs):
        fields = (
            ('customer_id', {'translated_name': 'customerIdExt'}),
            ('first_name', {'translated_name': 'firstName'}),
            ('last_name', {'translated_name': 'lastName'}),
            ('address1', {'required': False}),
            ('address2', {'required': False}),
            ('city', {'required': False}),
            ('state', {'required': False}),
            ('zip_code', {'required': False, 'translated_name': 'zip'}),
            ('phone', {'required': False}),
            ('email', {'required': False}),
            ('birth_date', {'required': False, 'translated_name': 'dob'}),
            ('ssn', {'required': False}),
            ('sex', {'required': False}),
        )
        requester = CustomerRequester(fields, kwargs)
        return self.send(command='add-consumer', requester=requester, resource=CustomerAddResource)

    def delete(self, **kwargs):
        fields = (
            ('id', {'translated_name': 'customerId'}),
        )
        requester = CustomerRequester(fields, kwargs)
        return self.send(command='delete-consumer', requester=requester, resource=CustomerDeleteResource)

    def update(self, **kwargs):
        fields = (
            ('id', {'translated_name': 'customerId'}),
            ('customer_id', {'translated_name': 'customerIdExt'}),
            ('first_name', {'required': False, 'blank': True, 'translated_name': 'firstName'}),
            ('last_name', {'required': False, 'blank': True, 'translated_name': 'lastName'}),
            ('address1', {'required': False, 'blank': True}),
            ('address2', {'required': False, 'blank': True}),
            ('city', {'required': False, 'blank': True}),
            ('state', {'required': False, 'blank': True}),
            ('zip_code', {'required': False, 'blank': True, 'translated_name': 'zip'}),
            ('phone', {'required': False, 'blank': True}),
            ('email', {'required': False, 'blank': True}),
            ('birth_date', {'required': False, 'blank': True, 'translated_name': 'dob'}),
            ('ssn', {'required': False, 'blank': True}),
            ('sex', {'required': False, 'blank': True}),
        )
        requester = CustomerRequester(fields, kwargs)
        return self.send(command='update-consumer', requester=requester, resource=CustomerUpdateResource)



# coding: utf-8
from maxipago.managers.base import ManagerTransaction, ManagerApi
from maxipago.requesters.payment import PaymentRecurringRequester


class PaymentRecurringManager(ManagerTransaction):

    def add(self, **kwargs):
        fields = (
            ('processor_id', {'translated_name': 'processorID'}),
            ('reference_num', {'translated_name': 'referenceNum'}),
            ('ip_address', {'translated_name': 'ipAddress', 'required': False}),

            ('card_number', {'translated_name': 'transactionDetail/payType/creditCard/number'}),
            ('card_expiration_month', {'translated_name': 'transactionDetail/payType/creditCard/expMonth'}),
            ('card_expiration_year', {'translated_name': 'transactionDetail/payType/creditCard/expYear'}),
            ('card_cvv', {'translated_name': 'transactionDetail/payType/creditCard/cvvNumber', 'required': False}),

            ('charge_total', {'translated_name': 'payment/chargeTotal'}),
            ('currency_code', {'translated_name': 'payment/currencyCode', 'required': True}),

            ('recurring_action', {'translated_name': 'recurring/action', 'default': 'new'}),
            ('recurring_start', {'translated_name': 'recurring/startDate'}),
            ('recurring_last', {'translated_name': 'recurring/lastDate'}),
            ('recurring_frequency', {'translated_name': 'recurring/frequency'}),
            ('recurring_period', {'translated_name': 'recurring/period'}),
            ('recurring_first_amount', {'translated_name': 'recurring/firstAmount'}),
            ('recurring_last_amount', {'translated_name': 'recurring/lastAmount'}),
            ('recurring_installments', {'translated_name': 'recurring/installments'}),
            ('recurring_failure_threshold', {'translated_name': 'recurring/failureThreshold', 'required': False}),
        )

        requester = PaymentRecurringRequester(fields, kwargs)
        return self.send(command='recurringPayment', requester=requester)

    def delete(self, **kwargs):
        fields = (
            ('order_id', {'translated_name': 'orderID'}),
        )

        requester = PaymentRecurringRequester(fields, kwargs)

        manager = ManagerApi(maxid=self.maxid, api_key=self.api_key, api_version=self.api_version, sandbox=self.sandbox)
        return manager.send(command='cancel-recurring', requester=requester)



# coding: utf-8


class Maxipago(object):

    def __init__(self, maxid, api_key, api_version='3.1.1.15', sandbox=False):
        self.maxid = maxid
        self.api_key = api_key
        self.api_version = api_version
        self.sandbox = sandbox

    def __getattr__(self, name):
        try:
            class_name = ''.join([n.title() for n in name.split('_') + ['manager']])
            module = __import__('maxipago.managers.{0}'.format(name), fromlist=[''])
            klass = getattr(module, class_name)
            return klass(self.maxid, self.api_key, self.api_version, self.sandbox)
        except ImportError:
            if name in self.__dict__:
                return self.__dict__.get('name')
        except AttributeError:
            raise AttributeError
